#!/bin/bash

{
if systemd-detect-virt --quiet; then
    EFI_PART=$(findmnt -no SOURCE /boot/efi)
    if ! echo "$EFI_PART" | grep -q -E '^/dev/'; then
        exit 0
    fi

    DISK=$(lsblk -no PKNAME "$EFI_PART" | head -n1)
    DEV="/dev/$DISK"
    PART_NUM=$(echo "$EFI_PART" | sed -E 's/.*[^0-9]([0-9]+)$/\1/')

    . /etc/os-release
    BOOT_LABEL="UEFI Shell"

    if echo "$ID" | grep -qi "sles"; then
        EFI_DIR="/boot/efi/EFI/sles"
        EFI_PATH='\\EFI\\sles\\Shell.efi'
		echo "sles"
	elif echo "$ID" | grep -qi "opensuse"; then
        EFI_DIR="/boot/efi/EFI/opensuse"
        EFI_PATH='\\EFI\\opensuse\\Shell.efi'
		echo "opensuse"
    else
        exit 0
    fi

    mkdir -p "$EFI_DIR"
    install -m 0644 /usr/share/ovmf/Shell.efi "$EFI_DIR/Shell.efi"

    efibootmgr -c -L "$BOOT_LABEL" -d "$DEV" -p "$PART_NUM" -l "$EFI_PATH"

    NEW_BOOTNUM=$(efibootmgr | grep "$BOOT_LABEL" | sed -n 's/^Boot\([0-9A-Fa-f]*\)\*.*/\1/p' | head -n1)
    CURRENT_ORDER=$(efibootmgr | grep '^BootOrder' | cut -d ' ' -f2 | tr -d '\n' | sed 's/,$//')
    if [ -n "$NEW_BOOTNUM" ]; then
        CLEANED_ORDER=$(echo "$CURRENT_ORDER" | sed "s/\b$NEW_BOOTNUM\b//g" | sed 's/,,*/,/g' | sed 's/^,//' | sed 's/,$//')
        efibootmgr -o "$CLEANED_ORDER,$NEW_BOOTNUM"
    fi
fi
} &> /dev/null